﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win.UltraWinGrid;
using Infragistics.Win;
using System.Reflection;
using Infragistics.Win.UltraWinGanttView.UIElements;
using Infragistics.Win.UltraWinSchedule.TimelineView;

namespace WindowsFormsApplication1
{
    public partial class MyControl : UserControl
    {
        bool hideGrid = false;
        MyCreation creation = new MyCreation(false);
        int gridAreaWidth = 0;

        public MyControl()
        {
            InitializeComponent();
            gridAreaWidth = ultraGanttView1.GridAreaWidth;
            ultraGanttView1.CreationFilter = creation;
        }

        [DefaultValue (false)]
        public bool HideGrid
        {
            get
            {
                return hideGrid;
            }
            set
            {
                if (value)
                {
                    gridAreaWidth = ultraGanttView1.GridAreaWidth;
                    ultraGanttView1.GridAreaWidth = 0;
                }
                else
                    ultraGanttView1.GridAreaWidth = gridAreaWidth;
                creation.HideGrid = value;
                hideGrid = value;
                ultraGanttView1.Refresh();
                ultraGanttView1.Invalidate();
            }
        }

    }

    class MyCreation : IUIElementCreationFilter
    {
        private bool hideGrid;

        private int width = 0;

        public bool HideGrid
        {
            get { return hideGrid; }
            set { hideGrid = value; }
        }

        public MyCreation(bool hideGrid)
        {
            // TODO: Complete member initialization
            this.hideGrid = hideGrid;
        }
        #region IUIElementCreationFilter Members

        public void AfterCreateChildElements(UIElement parent)
        {
            if (parent is TaskAreaUIElement && hideGrid && parent.HasChildElements)
            {
                width = parent.Rect.Width / parent.ChildElements.Count;
                Point loc = parent.ChildElements[0].Rect.Location;
                for (int i = 0; i < parent.ChildElements.Count; i++)
                {
                    parent.ChildElements[i].Rect = new Rectangle(loc,
                    new Size(width, parent.ChildElements[i].Rect.Height));
                    loc.Offset(width, 0);
                }
            }

            if (parent is ColumnHeaderAreaUIElement && hideGrid && parent.HasChildElements)
            {
                List<UIElement> header = parent.ChildElements.Where(el => ((ColumnHeaderUIElement)el).DateTimeInterval.IsPrimaryInterval).ToList<UIElement>();
                Point loc = header[0].Rect.Location;
                for (int i = 0; i < header.Count; i++)
                {
                    header[i].Rect = new Rectangle(loc,
                    new Size(width, header[0].Rect.Height));
                    loc.Offset(width, 0);
                }
            }
        }

        public bool BeforeCreateChildElements(UIElement parent)
        {
            if (hideGrid && (parent is GridAreaUIElement ||
                parent is VerticalSplitterUIElement))
                parent.Rect = new Rectangle(0, 0, 0, 0);
            if (parent is TimelineAreaUIElement && hideGrid)
                parent.Rect = parent.Parent.Rect;

            return false;
        }

        #endregion
    }
}
